@@ -1,10 +1,8 @@
 from . import core
 from . import utils
 
-from .core import header
 from .core.compiler import Setting, py_2_cpp, CppnizeResult
 from .core.jit import jit
 
 __all__ = ["core", "utils",
-           "header",
            "Setting", "py_2_cpp", "CppnizeResult", "jit"]
\ No newline at end of file
