@@ -16,7 +16,6 @@ from py2cpp.utils.parse import pad, unwrap_paren, CommentInfo, parse_comments
 path_here = Path(__file__).parent
 
 path_builtins = path_here / "builtins"
-path_header = path_here / "py2cpp_header.py"
 
 def _builtins_getIdx(last_idx: list[int] = [0]) -> int:
     v = last_idx[0]
@@ -977,15 +976,14 @@ def dfs(node: ast.Module | ast.stmt, type_ctx: TypeContext, state: State, depth:
 
         case ast.Import:
             assert type(node) == ast.Import
-            if len(node.names) == 1 and node.names[0].name in ("sys", "py2cpp_header"):
+            if node.names and node.names[0].name.split(".")[0] in ("sys", "py2cpp"):
                 pass
             else:
-                raise NotImplementedError("Only 'import py2cpp_header' is supported")
+                raise NotImplementedError("Only sys and py2cpp are supported")
 
         case ast.ImportFrom:
             assert type(node) == ast.ImportFrom
-            if node.module == "py2cpp_header":
-                pass
+            pass
 
         case ast.Continue:
             result += "continue;" + comments_now_code
@@ -1031,7 +1029,7 @@ def py_2_cpp(text: str, path: str = "<string>", *, setting: Setting | None = Non
     compile(text, filename=path, mode='exec', flags=ast.PyCF_ONLY_AST, dont_inherit=True, optimize=-1)
 
     _parse_types = get_time(parse_types) if verbose else parse_types
-    type_ctx = _parse_types(text, [str(path_header)])
+    type_ctx = _parse_types(text)
 
     tree = ast.parse(text, filename=path)
 
